@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +29,7 @@
 #include <stdio.h>
 
 #include "gstcdparanoiasrc.h"
-#include "gst/gst-i18n-plugin.h"
+#include <glib/gi18n-lib.h>
 
 enum
 {
@@ -59,6 +59,8 @@ GST_DEBUG_CATEGORY_STATIC (gst_cd_paranoia_src_debug);
 
 #define gst_cd_paranoia_src_parent_class parent_class
 G_DEFINE_TYPE (GstCdParanoiaSrc, gst_cd_paranoia_src, GST_TYPE_AUDIO_CD_SRC);
+GST_ELEMENT_REGISTER_DEFINE (cdparanoiasrc, "cdparanoiasrc", GST_RANK_SECONDARY,
+    GST_TYPE_CD_PARANOIA_SRC);
 
 static void gst_cd_paranoia_src_finalize (GObject * obj);
 static void gst_cd_paranoia_src_get_property (GObject * object, guint prop_id,
@@ -156,11 +158,9 @@ gst_cd_paranoia_src_class_init (GstCdParanoiaSrcClass * klass)
           75, DEFAULT_SEARCH_OVERLAP,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstCdParanoiaSrc:cache-size
+   * GstCdParanoiaSrc:cache-size:
    *
    * Set CD cache size to n sectors (-1 = auto)
-   *
-   * Since: 0.10.24
    */
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_CACHE_SIZE,
       g_param_spec_int ("cache-size", "Cache size",
@@ -171,7 +171,7 @@ gst_cd_paranoia_src_class_init (GstCdParanoiaSrcClass * klass)
   /* FIXME: we don't really want signals for this, but messages on the bus,
    * but then we can't check any longer whether anyone is interested in them */
   /**
-   * GstCdParanoiaSrc::transport-error
+   * GstCdParanoiaSrc::transport-error:
    * @cdparanoia: The CdParanoia instance
    * @sector: The sector number at which the error was encountered.
    *
@@ -182,9 +182,9 @@ gst_cd_paranoia_src_class_init (GstCdParanoiaSrcClass * klass)
       g_signal_new ("transport-error", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
       G_STRUCT_OFFSET (GstCdParanoiaSrcClass, transport_error),
-      NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
+      NULL, NULL, NULL, G_TYPE_NONE, 1, G_TYPE_INT);
   /**
-   * GstCdParanoiaSrc::uncorrected-error
+   * GstCdParanoiaSrc::uncorrected-error:
    * @cdparanoia: The CdParanoia instance
    * @sector: The sector number at which the error was encountered.
    *
@@ -195,7 +195,9 @@ gst_cd_paranoia_src_class_init (GstCdParanoiaSrcClass * klass)
       g_signal_new ("uncorrected-error", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
       G_STRUCT_OFFSET (GstCdParanoiaSrcClass, uncorrected_error),
-      NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
+      NULL, NULL, NULL, G_TYPE_NONE, 1, G_TYPE_INT);
+
+  gst_type_mark_as_plugin_api (GST_TYPE_CD_PARANOIA_MODE, 0);
 }
 
 static gboolean
@@ -511,12 +513,12 @@ gst_cd_paranoia_src_get_property (GObject * object, guint prop_id,
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
+  gboolean ret = FALSE;
+
   GST_DEBUG_CATEGORY_INIT (gst_cd_paranoia_src_debug, "cdparanoiasrc", 0,
       "CD Paranoia Source");
 
-  if (!gst_element_register (plugin, "cdparanoiasrc", GST_RANK_SECONDARY,
-          GST_TYPE_CD_PARANOIA_SRC))
-    return FALSE;
+  ret |= GST_ELEMENT_REGISTER (cdparanoiasrc, plugin);
 
 #ifdef ENABLE_NLS
   GST_DEBUG ("binding text domain %s to locale dir %s", GETTEXT_PACKAGE,
@@ -525,7 +527,7 @@ plugin_init (GstPlugin * plugin)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
 
-  return TRUE;
+  return ret;
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
